==> ouc_api-0.9.tar.gz: ouc_api-0.9/ouc_api/uia.py <==
from .baseApi import BaseAPI
import re
import base64
import json
import pycurl


class UIA(BaseAPI):
    def __init__(self):
        super(BaseAPI, self).__init__()

    def login(self, username, password):
        login_html = self.request("http://my.ouc.edu.cn")
        result = re.search('<input type="hidden" name="lt" value="(.+)" />', login_html)
        if result:
            login_code = result.group(1)
        result = self.request("http://id.ouc.edu.cn:8071/sso/ssoLogin ",
                              referer="http://id.ouc.edu.cn:8071/sso/login?service=http%3A%2F%2Fmy.ouc.edu.cn%2Fuser%2FsimpleSSOLogin",
                              params=dict(username=username, password=password,
                                          lt=login_code, _eventId="submit"))
        result = json.loads(result)
        if result["state"] is False:
            return dict(code=403, message="密码错误")
        result = self.request(
            "http://id.ouc.edu.cn:8071/sso/login?service=http%3A%2F%2Fmy.ouc.edu.cn%2Fuser%2FsimpleSSOLogin",
            referer="http://id.ouc.edu.cn:8071/sso/login?service=http%3A%2F%2Fmy.ouc.edu.cn%2Fuser%2FsimpleSSOLogin",
            params=dict(username=username, password=base64.b64encode(password.encode()),
                        lt=login_code, _eventId="submit"))
        if username in result:
            return dict(code=200, message="登陆成功")

    def get_user_info(self):
        url = "http://my.ouc.edu.cn/c/portal/baseUserInfoAction"
        html = self.request(url)
        result = json.loads(html)
        return result

    def login_yjs(self):
        url = "http://id.ouc.edu.cn:8071/app/forward.action?id=ff80808158001c18015800720148000e&userId=21170231232"
        self.http.set_option(pycurl.MAXREDIRS, 10)
        html = self.request("http://graduate.ouc.edu.cn/ssoLogin.do")

    def get_yjs_course(self, xn, xq):
        "http://graduate.ouc.edu.cn/stuelectcourse/listCourse.do?pagingNumberPer=20&depid=1&sortDirection=1&pagingPage=2"
        url = "http://graduate.ouc.edu.cn/stuelectcourse/listCourse.do?pagingNumberPer=20&depid=1&sortDirection=1&pagingPage={}"
        html = self.request(url)
        result = re.search("<b>(\d+)</b> / <b>(\d+)</b>", html)
        course = []
        lists = []
        if (result):
            max_page = int(result.group(2))
            for page in range(1, max_page + 1):
                html = self.request(url.format(page))
                result = self.get_table(html)
                course.extend(result[0])
        for x in course:
            x[8] = ' '.join(x[8].split())
            x[8] = x[8].replace("自排教室: ", "")
            """
            ['130K0059', '河口沉积物动力学', '1', '环境科学与工程学院', '3.0', '80',
             '72', '贾永刚', '5--20 星期一 第10-12节 三区3402(崂山校区)', '', '', '正常']
            """
            result = re.findall("(\d+)--(\d+) 星期(.) 第(\d+)-(\d+)节[^0-9]+(\d+)", x[8])
            if result:
                for y in result:
                    if len(y[5]) == 4:
                        course = dict(classNum=x[0], xn=xn, xq=xq,
                                      classRoom=y[5], teacher="".join(x[7].split()),
                                      name=x[1], weeks=self.get_weeks(int(y[0]), int(y[1])),
                                      num=int(y[4]) - int(y[3]), day=self.get_day(y[2]),
                                      begin=y[3], type="yjs",
                                      orgin=x[8])
                        lists.append(course)
        return lists

    def get_weeks(self, begin, end):
        result = ""
        if begin > 1:
            end = end - begin
            begin = 1
        for index in range(begin, end + 1):
            result += str(index) + ","
        return result[:-1]

    def get_day(self, strr):
        days = {"一": 1, "二": 2, "三": 3,
                "四": 4, "五": 5, "六": 6,
                "日": 7}
        if strr:
            return days.get(strr)
        else:
            return -1

==> ouc_api-1.1.tar.gz: ouc_api-1.1/ouc_api/uia.py <==
from .baseApi import BaseAPI
import re
import base64
import json
import pycurl


class UIA(BaseAPI):
    def __init__(self):
        super(BaseAPI, self).__init__()

    def login_uia(self, username, password):
        login_html = self.request("http://my.ouc.edu.cn")
        result = re.search('<input type="hidden" name="lt" value="(.+)" />', login_html)
        if result:
            login_code = result.group(1)
        result = self.request("http://id.ouc.edu.cn:8071/sso/ssoLogin ",
                              referer="http://id.ouc.edu.cn:8071/sso/login?service=http%3A%2F%2Fmy.ouc.edu.cn%2Fuser%2FsimpleSSOLogin",
                              params=dict(username=username, password=password,
                                          lt=login_code, _eventId="submit"))
        result = json.loads(result)
        if result["state"] is False:
            return dict(status=403, message="密码错误,请使用智慧海大账号登录")
        result = self.request(
            "http://id.ouc.edu.cn:8071/sso/login?service=http%3A%2F%2Fmy.ouc.edu.cn%2Fuser%2FsimpleSSOLogin",
            referer="http://id.ouc.edu.cn:8071/sso/login?service=http%3A%2F%2Fmy.ouc.edu.cn%2Fuser%2FsimpleSSOLogin",
            params=dict(username=username, password=base64.b64encode(password.encode()),
                        lt=login_code, _eventId="submit"))
        """
        <div class="username">罗梁</div><div class="role">教授</div><div class="dep">信息科学与技术学院</div>
        """

        if username in result:
            xm = ""
            zy = ""
            try:
                xm = re.search(r'<div class="username">(.+?)</div>', result).group(1)
                zy = re.search(r'<div class="dep">(.+?)</div>', result).group(1)
            except:
                pass
            return dict(status=200, message="登陆成功", name=xm, zy=zy, xh=username)
        else:
            return dict(status=203, message="系统错误，请联系管理员")

    def get_user_info(self):
        url = "http://my.ouc.edu.cn/c/portal/baseUserInfoAction"
        html = self.request(url)
        result = json.loads(html)
        return result

    def login_yjs(self, xh):
        self.http.set_option(pycurl.MAXREDIRS, 10)
        html = self.request("http://graduate.ouc.edu.cn/ssoLogin.do")

    def login_jwc(self, xh):
        self.request("http://jwgl.ouc.edu.cn/login")

    def get_yjs_course(self, xn, xq):
        "http://graduate.ouc.edu.cn/stuelectcourse/listCourse.do?pagingNumberPer=20&depid=1&sortDirection=1&pagingPage=2"
        url = "http://graduate.ouc.edu.cn/stuelectcourse/listCourse.do?pagingNumberPer=20&depid=1&sortDirection=1&pagingPage={}"
        html = self.request(url)
        result = re.search("<b>(\d+)</b> / <b>(\d+)</b>", html)
        course = []
        lists = []
        if (result):
            max_page = int(result.group(2))
            for page in range(1, max_page + 1):
                html = self.request(url.format(page))
                result = self.get_table(html)
                course.extend(result[0])
        for x in course:
            x[8] = ' '.join(x[8].split())
            x[8] = x[8].replace("自排教室: ", "")
            """
            ['130K0059', '河口沉积物动力学', '1', '环境科学与工程学院', '3.0', '80',
             '72', '贾永刚', '5--20 星期一 第10-12节 三区3402(崂山校区)', '', '', '正常']
            """
            result = re.findall("(\d+)--(\d+) 星期(.) 第(\d+)-(\d+)节[^0-9]+(\d+)", x[8])
            if result:
                for y in result:
                    if len(y[5]) == 4:
                        course = dict(classNum=x[0], xn=xn, xq=xq,
                                      classRoom=y[5], teacher="".join(x[7].split()),
                                      name=x[1], weeks=self.get_weeks(int(y[0]), int(y[1])),
                                      num=int(y[4]) - int(y[3]), day=self.get_day(y[2]),
                                      begin=y[3], type="yjs",
                                      orgin=x[8])
                        lists.append(course)
        return lists

    def get_weeks(self, begin, end):
        result = ""
        if begin > 1:
            end = end - begin
            begin = 1
        for index in range(begin, end + 1):
            result += str(index) + ","
        return result[:-1]

    def get_day(self, strr):
        days = {"一": 1, "二": 2, "三": 3,
                "四": 4, "五": 5, "六": 6,
                "日": 7}
        if strr:
            return days.get(strr)
        else:
            return -1
